/*
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/**
 * API for programmatic invocation of XJC and schemagen.
 *
 * <p>
 * This package provides a way to invoke XJC from within another program. The primary target of this API is the JAX-WS
 * RI, but we hope that this API would be useful for other integration purposes as well.
 *
 * <h2>Getting Started: Using XJC</h2>
 * <p>
 * To invoke XJC, a typical client would do something like this:
 * <pre>
 *    SchemaCompiler sc = XJC.createSchemaCompiler();
 *    sc.parseSchema(new InputSource(schema1Url.toExternalForm()));
 *    sc.parseSchema(new InputSource(schema2Url.toExternalForm()));
 *    ...
 *    S2JModel model = sc.bind();
 * </pre>
 * <p>
 * The bind operation causes XJC to do the bulk of the work, such as figuring out what classes to generate, what
 * methods/fields to generate, etc. The obtained model contains useful introspective information about how the binding
 * was performed (such as the mapping between XML types and generated Java classes)
 *
 * <p>
 * Once the model is obtained, generate the code into the file system as follows:
 * <pre>
 *   JCodeModel cm = model.generateCode( null, ... );
 *   cm.build(new FileCodeWriter(outputDir));
 * </pre>
 *
 * <h2>Implementation Note</h2>
 * <p>
 * This package shouldn't contain any implementation code.
 */
package com.sun.tools.internal.xjc.api;
